summaryrefslogtreecommitdiffstats
path: root/kdesktop/desktop.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdesktop/desktop.h')
-rw-r--r--kdesktop/desktop.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesktop/desktop.h b/kdesktop/desktop.h
index 4d3a81750..cad822fc2 100644
--- a/kdesktop/desktop.h
+++ b/kdesktop/desktop.h
@@ -96,7 +96,7 @@ public:
void logout( KApplication::ShutdownConfirm confirm, KApplication::ShutdownType sdtype );
- KWinModule* kwinModule() const { return m_pKwinmodule; }
+ KWinModule* twinModule() const { return m_pKwinmodule; }
// The action collection of the active widget
KActionCollection *actionCollection();
@@ -153,7 +153,7 @@ private slots:
/** Connected to KDIconView and KRootWidget */
void slotSwitchDesktops(int delta);
// when there seems to be no kicker, we have to get desktopIconsArea from kwinModule
void slotNoKicker();
/** Used for desktop show/hide functionality */
@@ -153,7 +153,7 @@ private slots:
/** Connected to KDIconView and KRootWidget */
void slotSwitchDesktops(int delta);
- // when there seems to be no kicker, we have to get desktopIconsArea from kwinModule
+ // when there seems to be no kicker, we have to get desktopIconsArea from twinModule
void slotNoKicker();
/** Used for desktop show/hide functionality */